OC.L10N.register(
    "tasks",
    {
    "Important" : "اہم",
    "Today" : "آج",
    "Week" : "ہفتہ",
    "Tasks" : "کام",
    "Edit" : "تدوین کریں",
    "Download" : "ڈاؤن لوڈ",
    "Delete" : "حذف کریں",
    "Unshare" : "شئیرنگ ختم کریں",
    "Cancel" : "منسوخ کریں",
    "Save" : "حفظ"
},
"nplurals=2; plural=(n != 1);");
